execline: the forstdin command
Keywords: execline command forstdin

execline
Software
skarnet.org

# The `forstdin` program

`forstdin` uses its input as loop elements to run another program.

## Interface

In an execlineb script:

         forstdin [ -p | -o okcodes | -x breakcodes ] [ -n ] [ -C | -c ] [ -0 | -d delim ] variable loop...

- `forstdin` reads its standard input as it becomes available, splitting it automatically.
- For every argument x in the split output, `forstdin` runs loop... as a child process, with variable=x added to its environment.
- `forstdin` then exits 0.

## Options

- `-p` : parallel mode. Do not wait for a loop... instance to finish before spawning the next one. forstdin will still wait for all instances of loop to terminate before exiting, though.
- `-0` : accept null characters on its stdin, using them as delimiters. If this option and a `-d` option are used simultaneously, the rightmost one wins.
- `-o` okcodes : okcodes must be a comma-separated list of exit codes. If the `-p` flag hasn't been given and loop exits with one of the codes in okcodes, forstdin will run the following instances of the loop, but if the exit code is not listed in okcodes, forstdin will exit immediately with an approximation of the same exit code.
- `-x` breakcodes : like the previous option, but with inverted meaning - the listed exit codes are codes that will make forstdin break the loop and exit, and the unlisted exit codes will make it keep looping.
- Other options are used to control the substitution mechanism for every x. Of course, you can't split x.

## Notes

- You can start loop... with "import -u variable" to perform variable substitution.